# Cloud Backup and DR Logging Integration

The proto files in this directory serve as documentation for the format of the event Logs with Backup and DR Service. Event logs is used to view the operations performed in Backup and DR Service. Backup/recovery appliances produce events with event IDs and associated error messages. In many cases, additional information is provided in the form of error codes with their own associated error messages that come from the underlying component that experienced an error or warning that in turn produced an event.
